#!/bin/sh

export PYTHONPATH=../

pytest -v
